"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var https_1 = require("https");
var streak = {
    best: 0,
    current: 0,
};
var contributions = {
    best: 0,
    total: 0,
    current: 0,
};
var parseBody = function (body) {
    var matches = [];
    var regex = /data-count="(.*?)"/g;
    var found;
    // eslint-disable-next-line no-cond-assign
    while ((found = regex.exec(body)))
        matches.push(found);
    matches.forEach(function (match) {
        var count = parseInt(match[1], 10);
        contributions.total += count;
        contributions.current = count;
        if (count > contributions.best)
            contributions.best = count;
        streak.current = count > 0 ? (streak.current += 1) : 0;
        if (streak.current > streak.best)
            streak.best = streak.current;
    });
    return { streak: streak, contributions: contributions };
};
var fetchStats = function (username, options) {
    if (options === void 0) { options = {}; }
    var enableCors = !!options.enableCors;
    var url = "https://github.com/users/" + username + "/contributions";
    if (enableCors)
        url = "https://cors-anywhere.herokuapp.com/" + url;
    return new Promise(function (resolve, reject) {
        https_1.get(url, function (response) {
            var body = '';
            response.setEncoding('utf8');
            response.on('data', function (chunk) {
                body += chunk;
            });
            response.on('end', function () {
                if (response.statusCode === 404) {
                    if (options.onFailure)
                        return options.onFailure(response);
                    return reject(response);
                }
                var data = parseBody(body);
                if (options.onSuccess)
                    return options.onSuccess(data);
                return resolve(data);
            });
        });
    });
};
exports.fetchStats = fetchStats;
